<?xml version="1.0" encoding="UTF-8"?>
<!-- This file generated by Dropcaster <%= Dropcaster::VERSION %> -->
<rss xmlns:itunes="http://www.itunes.com/dtds/podcast-1.0.dtd" version="2.0">
  <channel>
    <title><%= h(title) %></title>
    <link><%= h(url) %></link>
    <description><%= h(description) %></description>
    <itunes:summary><%= h(description) %></itunes:summary>
    <itunes:block>yes</itunes:block>
    <googleplay:block>yes</googleplay:block>
    <% unless language.blank? %>
    <language><%= h(language) %></language>
    <% end %>
    <% unless copyright.blank? %>
    <copyright><%= h(copyright) %></copyright>
    <% end %>
    <% unless subtitle.blank? %>
    <itunes:subtitle><%= h(subtitle) %></itunes:subtitle>
    <% end %>
    <% unless author.blank? %>
    <itunes:author><%= h(author) %></itunes:author>
    <% end %>
    <% unless owner.nil? %>
    <itunes:owner>
      <itunes:name><%= h(owner[:name]) %></itunes:name>
      <itunes:email><%= h(owner[:email]) %></itunes:email>
    </itunes:owner>
    <% end %>
    <% unless image_url.blank? %>
    <itunes:image href="<%= image_url %>"/>
    <% end %>
  <% categories.each{|category| %>
    <% if category.respond_to?(:each_line) %>
    <itunes:category text="<%= h(category) %>"/>
    <% else %>
    <itunes:category text="<%= h(category.first) %>">
      <itunes:category text="<%= h(category.last) %>"/>
    </itunes:category>
    <% end %>
  <% } unless categories.blank? %>
  <% unless explicit.blank? %>
    <itunes:explicit><%= h(explicit) %></itunes:explicit>
  <% end %>
	<generator>Dropcaster <%= Dropcaster::VERSION%></generator>
	<% unless keywords.blank? %>
    <itunes:keywords><%= keywords.map{|k| h(k)}.join(',') %></itunes:keywords>
  <% end %>
  <% items.each{|item| %>
    <item>
      <title><%= h(item.tag.title || item.file_path.to_s) %></title>
      <itunes:author><%= h(item.tag.artist) %></itunes:author>
    <% unless item.tag2.TT3.blank? && item.tag2.TIT3.blank? %>
      <itunes:subtitle><%= h(truncate(item.tag2.TT3 || item.tag2.TIT3, 50)) %></itunes:subtitle>
      <itunes:summary><%= h(item.tag2.TT3 || item.tag2.TIT3) %></itunes:summary>
    <% end %>
      <itunes:image href="<%= item.image_url %>"/>
      <enclosure url="<%= item.url %>" length="<%= item.file_size %>" type="audio/mp3"/>
      <link><%= item.url %></link>
      <guid isPermaLink="false"><%= h(item.uuid) %></guid>
      <pubDate><%= h(item.pub_date.to_formatted_s(:rfc822)) %></pubDate>
      <itunes:duration><%= item.duration.to_i %></itunes:duration>
    <% unless item.keywords.blank? %>
      <itunes:keywords><%= item.keywords.map{|k| h(k)}.join(',') %></itunes:keywords>
    <% end %>
    </item>
  <% } %>
  </channel>
</rss>
